@@ -1,7 +1,7 @@
 /*=============================================================================
 ttyrpld - TTY replay daemon
 include/rdsh.h - Shared definitions for RPLD/INFO/RPLINFO
-  Copyright (C) Jan Engelhardt <jengelh [at] linux01 gwdg de>, 2004
+  Copyright © Jan Engelhardt <jengelh [at] linux01 gwdg de>, 2004
   -- License restrictions apply (GPL2)
 
   This file is part of ttyrpld.
@@ -28,9 +28,9 @@ include/rdsh.h - Shared definitions for RPLD/INFO/RPLINFO
 #include <pthread.h>
 #include <stdint.h>
 #include <libHX.h>
-#if LIBHX_VERSION < 20040908
+#if !defined(_LIBHX_H) || _LIBHX_H < 20041024
 #    error --------------------------------------------
-#    error You need a newer version of libHX (20040908)
+#    error You need a newer version of libHX (20041024)
 #    error --------------------------------------------
 #endif
 
@@ -44,7 +44,7 @@ struct GOptmap_t {
 };
 
 struct Statmap_t {
-    size_t open, read, write, ioctl, close, badpack;
+    size_t init, open, read, write, ioctl, close, deinit, badpack;
     unsigned long long in, out;
 };
 
@@ -57,15 +57,28 @@ struct tty {
 };
 
 enum {
+    // req(void)
     IFP_NONE = 0,
-    IFP_ACTIVATE,
-    IFP_DEACTIVATE,
-    IFP_DEACTIVSES, // deactivate logging until tty is closed
-    IFP_GETINFO_T,
-    IFP_GETINFO,
-    IFP_REMOVE,
+    IFT_VOID_START,
     IFP_FLUSH,
     IFP_ZERO,
+    IFT_VOID_STOP,
+
+    // req(uint32_t)
+    IFT_INT_START = 0x40,
+    IFP_ACTIVATE,
+    IFP_DEACTIVATE,
+    IFP_DEACTIVSES,
+    IFP_REMOVE,
+    IFP_GETINFO,
+    IFP_GETINFO_T,
+    IFT_INT_STOP,
+
+    // req(const char *)
+    IFT_STR_START = 0x80,
+    IFP_ENABUSER,
+    IFP_DEACUSER,
+    IFT_STR_STOP,
 
     NF_NEWLINE = 1 << 0,
 };
