@@ -42,6 +42,11 @@ kernel/rpldev.c - Kernel interface for RPLD
 #ifndef __user
 #    define __user
 #endif
+#if __GNUC__ == 3 && __GNUC_MINOR__ >= 4
+#    define XINLINE
+#else
+#    define XINLINE inline
+#endif
 
 #if LINUX_VERSION_CODE < KERNEL_VERSION(2, 6, 0)
 #    define KERNEL_2_4 1
@@ -81,14 +86,14 @@ static unsigned int uif_poll(struct file *, poll_table *);
 static int uif_close(struct inode *, struct file *);
 
 // Local functions
-inline static ssize_t avail_R(void);
-inline static ssize_t avail_W(void);
-inline static unsigned int imin_uint(unsigned int, unsigned int);
-inline static void get_tty_devnr(uint32_t *, struct tty_struct *);
+XINLINE static ssize_t avail_R(void);
+XINLINE static ssize_t avail_W(void);
+XINLINE static unsigned int imin_uint(unsigned int, unsigned int);
+XINLINE static void get_tty_devnr(uint32_t *, struct tty_struct *);
 static int mv_buffer(struct rpld_packet *, const char *, size_t);
-inline static void mv_buffer2(const void *, size_t);
-inline static void mv_to_user(char __user *, size_t);
-inline static void my_swab(void *, size_t);
+XINLINE static void mv_buffer2(const void *, size_t);
+XINLINE static void mv_to_user(char __user *, size_t);
+XINLINE static void my_swab(void *, size_t);
 
 // Variables
 static DECLARE_WAIT_QUEUE_HEAD(Inqueue);
@@ -368,19 +373,19 @@ static int uif_close(struct inode *inode, struct file *filp) {
 }
 
 //-----------------------------------------------------------------------------
-inline static ssize_t avail_R(void) {
+XINLINE static ssize_t avail_R(void) {
     // Return the number of available bytes to read
     if(BufWP >= BufRP) { return BufWP - BufRP; }
     return BufWP + Bufsize - BufRP;
 }
 
-inline static ssize_t avail_W(void) {
+XINLINE static ssize_t avail_W(void) {
     // Return the number of available bytes to write
     if(BufWP >= BufRP) { return BufRP + Bufsize - BufWP - 1; }
     return BufRP - BufWP - 1;
 }
 
-inline static void get_tty_devnr(uint32_t *dev, struct tty_struct *tty) {
+XINLINE static void get_tty_devnr(uint32_t *dev, struct tty_struct *tty) {
     // Get some unique number to identify the thing
 #ifdef KERNEL_2_4
     *dev = tty->device;
@@ -390,7 +395,7 @@ inline static void get_tty_devnr(uint32_t *dev, struct tty_struct *tty) {
     return;
 }
 
-inline static unsigned int imin_uint(unsigned int a, unsigned int b) {
+XINLINE static unsigned int imin_uint(unsigned int a, unsigned int b) {
     return a < b ? a : b;
 }
 
@@ -421,7 +426,7 @@ static int mv_buffer(struct rpld_packet *p, const char *buf, size_t count) {
     return count;
 }
 
-inline static void mv_buffer2(const void *src, size_t count) {
+XINLINE static void mv_buffer2(const void *src, size_t count) {
     /* This function is responsible for copying (a specific amount of
     arbitrary data) into the circulary buffer. (Taking the wrappage into
     account!) The parent function -- mv_buffer() in this case -- must make sure
@@ -440,7 +445,7 @@ inline static void mv_buffer2(const void *src, size_t count) {
     return;
 }
 
-inline static void mv_to_user(char __user *dest, size_t count) {
+XINLINE static void mv_to_user(char __user *dest, size_t count) {
     /* mv_to_user() reads COUNT bytes from the circulary buffer and puts it
     into userspace memory. */
     int x = Buffer + Bufsize - BufRP;
@@ -459,7 +464,7 @@ inline static void mv_to_user(char __user *dest, size_t count) {
     return;
 }
 
-inline static void my_swab(void *srcp, size_t count) {
+XINLINE static void my_swab(void *srcp, size_t count) {
     if(count == 16) {
         uint16_t *ptr = srcp;
         *ptr = cpu_to_le16(*ptr);
