@@ -1,7 +1,7 @@
 /*=============================================================================
 ttyrpld - TTY replay daemon
 user/infod.c - INFO socket for RPLD
-  Copyright (C) Jan Engelhardt <jengelh [at] linux01 gwdg de>, 2004
+  Copyright © Jan Engelhardt <jengelh [at] linux01 gwdg de>, 2004
   -- License restrictions apply (GPL2)
 
   This file is part of ttyrpld.
@@ -43,7 +43,7 @@ user/infod.c - INFO socket for RPLD
 // Function prototypes
 static void *client_thread(void *);
 static void flush_table(void);
-static void set_status(uint32_t, int);
+static void set_session_status(uint32_t, int);
 static void getinfo_text(uint32_t, int);
 static void getinfo(uint32_t, int);
 static void zero_counters(void);
@@ -98,49 +98,65 @@ static void *client_thread(void *arg) {
     while(1) {
         static const uint32_t zero = 0;
         unsigned char req;
-        uint32_t dev;
+        uint32_t gint; // general int
+        char buf[4096];
 
-        if(!RECEIVE_FULL(fd, &req, sizeof(unsigned char)) || req == IFP_NONE ||
-         !RECEIVE_FULL(fd, &dev, sizeof(uint32_t))) {
+        if(!RECEIVE_FULL(fd, &req, sizeof(unsigned char)) || req == IFP_NONE) {
             break;
+        } else if(req > IFT_INT_START && req < IFT_INT_STOP) {
+            if(!RECEIVE_FULL(fd, &gint, sizeof(uint32_t))) { break; }
+            PP_swab(&gint, sizeof(uint32_t));
+        } else if(req > IFT_STR_START && req < IFT_STR_STOP) {
+            if(!RECEIVE_FULL(fd, &gint, sizeof(uint32_t))) { break; }
+            PP_swab(&gint, sizeof(uint32_t));
+            if(!RECEIVE_FULL(fd, buf, min_uint(sizeof(buf), gint))) { break; }
         }
 
-        PP_swab(&dev, sizeof(uint32_t));
-
         switch(req) {
-            case IFP_ACTIVATE ... IFP_DEACTIVSES:
-                set_status(dev, req);
-                break;
-            case IFP_GETINFO_T:
-                getinfo_text(dev, fd);
-                break;
-            case IFP_GETINFO:
-                getinfo(dev, fd);
-                break;
-            case IFP_REMOVE: {
-                struct tty *tty;
-
-                pthread_mutex_lock(&Ttys_lock);
-                tty = get_tty(dev);
-                pthread_mutex_unlock(&Ttys_lock);
-
-                if(tty != NULL) { log_close(tty); }
-                break;
-            }
+            // Voids
             case IFP_FLUSH:
                 flush_table();
                 break;
             case IFP_ZERO:
                 zero_counters();
                 break;
+
+            // Integers
+            case IFP_ACTIVATE ... IFP_DEACTIVSES:
+                set_session_status(gint, req);
+                break;
+            case IFP_REMOVE: {
+                struct tty *tty;
+
+                pthread_mutex_lock(&Ttys_lock);
+                tty = get_tty(gint);
+                pthread_mutex_unlock(&Ttys_lock);
+
+                if(tty != NULL) { log_close(tty); }
+                break;
+            }
+            case IFP_GETINFO:
+                getinfo(gint, fd);
+                break;
+            case IFP_GETINFO_T:
+                getinfo_text(gint, fd);
+                break;
+
+            // Strings
+            // currently none
+
+            // Other
             default:
-                notify(LOG_WARNING, NF_NEWLINE, "Unknown request %d\n", req);
+                notify(LOG_WARNING, NF_NEWLINE, "Unknown request %d, closing"
+                 " connection to not run into conversion problems.\n", req);
+                goto clthr__exit;
                 break;
         }
 
         send_wait(fd, &zero, sizeof(uint32_t), 0);
     }
 
+clthr__exit:
     close(fd);
     return NULL;
 }
@@ -176,11 +192,11 @@ static void getinfo_text(uint32_t dev, int fd) {
           "%2s %8s %-7s %9s %9s %4s %s\n"
           "==========================================================================\n"
           "  [---,---] *       %9llu %9llu    -\n"
-          "            opn/cls: %zu/%zu  r/w: %zu/%zu  ioctl: %zu  bad: %zu\n"
+          "            IOCD: %zu/%zu/%zu/%zu  RW: %zu/%zu  I: %zu  B: %zu\n"
           "--------------------------------------------------------------------------\n",
           "AC", "DEVICE", "TTY", "BYTES IN", "OUT", "FD", "FILENAME",
-          Stats.in, Stats.out, Stats.open, Stats.close, Stats.read, Stats.write,
-          Stats.ioctl, Stats.badpack
+          Stats.in, Stats.out, Stats.init, Stats.open, Stats.close,
+          Stats.deinit, Stats.read, Stats.write, Stats.ioctl, Stats.badpack
         );
 
         pthread_mutex_lock(&Ttys_lock);
@@ -214,9 +230,9 @@ static void getinfo(uint32_t dev, int fd) {
         struct HXbtree_node *nd;
         struct HXbtrav *travp;
 
-        skprintf(fd, "%zu %zu %zu %zu %llu %llu %zu %zu\n",
-         Stats.open, Stats.close, Stats.read, Stats.write, Stats.in, Stats.out,
-         Stats.ioctl, Stats.badpack
+        skprintf(fd, "%zu %zu %zu %zu %zu %zu %llu %llu %zu %zu\n",
+          Stats.init, Stats.open, Stats.close, Stats.deinit, Stats.read,
+          Stats.write, Stats.in, Stats.out, Stats.ioctl, Stats.badpack
         );
 
         pthread_mutex_lock(&Ttys_lock);
@@ -243,7 +259,7 @@ static void getinfo(uint32_t dev, int fd) {
     return;
 }
 
-static void set_status(uint32_t dev, int req) {
+static void set_session_status(uint32_t dev, int req) {
     struct tty *tty;
 
     pthread_mutex_lock(&Ttys_lock);
