@@ -1,7 +1,7 @@
 /*=============================================================================
 ttyrpld - TTY replay daemon
 user/replay.c - Realtime TTY log analyzer
-  Copyright (C) Jan Engelhardt <jengelh [at] linux01 gwdg de>, 2004
+  Copyright © Jan Engelhardt <jengelh [at] linux01 gwdg de>, 2004
   -- License restrictions apply (GPL2)
 
   This file is part of ttyrpld.
@@ -182,7 +182,7 @@ static int replay_file(int fd, const char *name) {
         PP_swab(&packet.tv.tv_usec, sizeof(packet.tv.tv_usec));
 
         switch(packet.event) {
-            case EV_WRITE:
+            case EVT_WRITE:
                 if(ps.sktype == PCTRL_SKPACK && ps.skval-- > 0) {
                     read_nullfm(fd, packet.size);
                     break;
@@ -245,12 +245,12 @@ static int replay_file(int fd, const char *name) {
                     write(STDOUT_FILENO, buf, strlen(buf));
                 }
                 break;
-            case EV_IDENT:
+            case EVT_IDENT:
                 fprintf(stderr, "\n" "Created using ");
                 read_through(fd, STDERR_FILENO, packet.size);
                 fprintf(stderr, "\n");
                 break;
-            case EV_CLOSE:
+            case EVT_DEINIT:
                 fprintf(stderr, "\n" "<tty device has been closed>\n");
                 // fallthrough
             default:
@@ -289,7 +289,7 @@ static unsigned long calc_ovcorr(unsigned long ad, int rd) {
     }
 
     av /= rd;
-    fprintf(stderr, " %lu s\n", av);
+    fprintf(stderr, " %lu µs\n", av);
     return av;
 }
 
@@ -570,8 +570,8 @@ static int usleep_ovcorr(struct timeval *req, long *skew) {
       >normal  kernel  timer mechanism, which has a resolution of
       >1/HZ s (i.e, 10 ms on Linux/i386 and 1 ms on Linux/Alpha).
 
-    (*) for i386/2.4: HZ=100, i.e. 10 ms (10000 s)
-        for  all/2.6: HZ=1000, i.e. 1 ms (1000 s)
+    (*) for i386/2.4: HZ=100, i.e. 10 ms (10000 µs)
+        for  all/2.6: HZ=1000, i.e. 1 ms (1000 µs)
 
       >Therefore, nanosleep pauses always for at least the speci-
       >fied time, however it can take up to  10  ms  longer  than
@@ -654,7 +654,7 @@ static int usleep_ovcorr(struct timeval *req, long *skew) {
 static void tv_delta(const struct timeval *past, const struct timeval *now,
  struct timeval *dest) {
     /* Calculates the time difference between "past" and "now" and stores the
-    result in "dest". All parameters in s. */
+    result in "dest". All parameters in µs. */
     unsigned long sec = now->tv_sec - past->tv_sec;
     long acc = now->tv_usec - past->tv_usec;
 
