@@ -1,7 +1,7 @@
 /*=============================================================================
 ttyrpld - TTY replay daemon
 user/rpld.c - User space daemon (filtering, etc.)
-  Copyright (C) Jan Engelhardt <jengelh [at] linux01 gwdg de>, 2004
+  Copyright © Jan Engelhardt <jengelh [at] linux01 gwdg de>, 2004
   -- License restrictions apply (GPL2)
 
   This file is part of ttyrpld.
@@ -133,7 +133,7 @@ int main(int argc, const char **argv) {
 
     if((Ttys = HXbtree_init(HXBT_ASSOC | HXBT_LKEY | HXBT_XCPY | HXBT_FCMP,
      value_cmp)) == NULL) {
-        perror("HXbtree_init()");
+        perror("Ttys = HXbtree_init()");
         return EXIT_FAILURE;
     }
 
@@ -225,52 +225,47 @@ static void mainloop(int fd) {
 static int packet_action1(struct mem_packet *packet) {
     /* pty masters are an exact copy of their slaves,
     so no need to record them too. */
-    register long maj = K26_MAJOR(packet->dev);
+    {
+        register long maj = K26_MAJOR(packet->dev);
 
-    if(maj >= 128 && maj < 136 /* Unix98 ptm (-) */) {
-        if(packet->event != EV_CLOSE) { return 0; }
-        /* When closing an xterm window or SSH session, the EV_CLOSE event
-        actually happens on the master side. To keep it easy, it's device
-        signature is simply changed to the slave. */
-        packet->dev = K26_MKDEV(K26_MAJOR(packet->dev) + 8,
-         K26_MINOR(packet->dev));
-    } else if(maj == 2 /* BSD ptm (/dev/ptypXY) */) {
-        if(packet->event != EV_CLOSE) { return 0; }
-        packet->dev = K26_MKDEV(K26_MAJOR(3), K26_MINOR(packet->dev));
+        if(maj >= 128 && maj < 136 /* Unix98 ptm (-) */) {
+            if(packet->event != EVT_DEINIT) { return 0; }
+            /* When closing a pty, the EVT_DEINIT is generated on the master
+            side. To keep it easy, it's device signature is simply changed to
+            the slave. */
+            packet->dev = K26_MKDEV(K26_MAJOR(packet->dev) + 8,
+             K26_MINOR(packet->dev));
+        } else if(maj == 2 /* BSD ptm (/dev/ptypXY) */) {
+            if(packet->event != EVT_DEINIT) { return 0; }
+            packet->dev = K26_MKDEV(K26_MAJOR(3), K26_MINOR(packet->dev));
+        }
     }
 
     /* The excluded ptm packets above are not counted at all, whereas
     "ignored" packets are. See below for ignore rules. */
+    {
+        static int *tab[] = {
+            [EVT_INIT]   = &Stats.init,
+            [EVT_OPEN]   = &Stats.open,
+            [EVT_READ]   = &Stats.read,
+            [EVT_WRITE]  = &Stats.write,
+            [EVT_IOCTL]  = &Stats.ioctl,
+            [EVT_CLOSE]  = &Stats.close,
+            [EVT_DEINIT] = &Stats.deinit,
+        };
+        register int e = packet->event;
 
-    switch(packet->event) {
-        case EV_OPEN:
-            ++Stats.open;
-            break;
-        case EV_READ:
-            ++Stats.read;
-            Stats.in += packet->size;
-            break;
-        case EV_WRITE:
-            ++Stats.write;
-            Stats.out += packet->size;
-            break;
-        case EV_IOCTL:
-            ++Stats.ioctl;
-            break;
-        case EV_CLOSE:
-            ++Stats.close;
-            break;
-        default:
+        if(e >= sizeof(tab) / sizeof(int *) || tab[e] == NULL) {
             notify(LOG_WARNING, NF_NEWLINE, "Unknown packet type 0x%X\n",
              packet->event);
             return 0;
-    }
+        }
 
-    if(packet->event == EV_IOCTL) {
-        /* ioctl requests are actually logged by the rpldev Kernel module,
-        and I do see a use for them. But: it's simply not
-        implemented yet ;-) */
-        return 0;
+        if(e == EVT_READ) { Stats.in += packet->size; }
+        else if(e == EVT_WRITE) { Stats.out += packet->size; }
+
+        ++*tab[e];
+        if(e == EVT_IOCTL) { return 0; } // no use for ioctls ATM
     }
 
     return 1;
@@ -283,10 +278,10 @@ static int packet_action2(struct mem_packet *packet, struct tty *tty) {
         return 0;
     }
     switch(packet->event) {
-        case EV_READ:
+        case EVT_READ:
             tty->in += packet->size;
             break;
-        case EV_WRITE:
+        case EVT_WRITE:
             tty->out += packet->size;
             break;
     }
@@ -295,16 +290,16 @@ static int packet_action2(struct mem_packet *packet, struct tty *tty) {
 
 static int packet_action3(struct mem_packet *packet, struct tty *tty, int fd) {
     switch(packet->event) {
-        case EV_OPEN:
-            /* EV_OPEN is not handled since a logfile will automatically be opened
-            in log_write() if necessary. */
+        case EVT_OPEN:
+            /* EVT_OPEN is not handled since a logfile will automatically be
+            opened in log_write() if necessary. */
             log_cuid(tty);
             break;
-        case EV_READ:
-        case EV_WRITE:
+        case EVT_READ:
+        case EVT_WRITE:
             log_write(packet, tty, fd);
             break;
-        case EV_CLOSE:
+        case EVT_DEINIT:
             log_close(tty);
             break;
     }
@@ -366,7 +361,7 @@ static int log_open(struct tty *tty) {
     // ident header (optional)
     if(tty->fd >= 0) {
         struct disk_packet p = {
-            .event = EV_IDENT,
+            .event = EVT_IDENT,
             .magic = MAGIC_SIG,
             .tv    = {-1, -1},
         };
@@ -557,9 +552,9 @@ static void sighandler_int(int s) {
 }
 
 static void sighandler_alrm(int s) {
-    fprintf(stderr, "\r\e[2K" "opn/cls: %zu/%zu  r/w: %zu/%zu (%llu/%llu)"
-      " ioctl: %zu  bad: %zu",
-      Stats.open, Stats.close, Stats.read, Stats.write, Stats.in,
+    fprintf(stderr, "\r\e[2K" "IOCD: %zu/%zu/%zu/%zu  RW: %zu/%zu (%llu/%llu)"
+      " C: %zu  B: %zu",
+      Stats.init, Stats.open, Stats.close, Stats.deinit, Stats.read, Stats.write, Stats.in,
       Stats.out, Stats.ioctl, Stats.badpack
     );
     if(GOpt.verbose) { alarm(1); }
